
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#include <glib-object.h>

#if !defined(_LIBAPERTURE_INSIDE) && !defined(_LIBAPERTURE_COMPILATION)
#error "Only <aperture.h> can be included directly."
#endif

G_BEGIN_DECLS

/* enumerations from "aperture-utils.h" */


GType aperture_barcode_get_type (void);
#define APERTURE_TYPE_BARCODE (aperture_barcode_get_type())

/* enumerations from "aperture-viewfinder.h" */


GType aperture_viewfinder_state_get_type (void);
#define APERTURE_TYPE_VIEWFINDER_STATE (aperture_viewfinder_state_get_type())


GType aperture_media_capture_error_get_type (void);
#define APERTURE_TYPE_MEDIA_CAPTURE_ERROR (aperture_media_capture_error_get_type())

G_END_DECLS

/* Generated data ends here */

