/*
 * Autogenerated by the Meson build system.
 * Do not edit, your changes will be lost.
 */

#pragma once

#define APERTURE_MAJOR_VERSION 0

#define APERTURE_MICRO_VERSION 0

#define APERTURE_MINOR_VERSION 1

